function PartitionedEntities=read_PartitionedEntities(fid,varargin)
  p = inputParser;
  p.addParamValue('verbose',false,@islogical);
  p.parse(varargin{:});
  verbose=p.Results.verbose;
  flag=fc_oogmsh.msh.find_section(fid,'$PartitionedEntities','optional',true,varargin{:});
  if ~flag,PartitionedEntities=[];return;end
    
  PartitionedEntities=struct('numPartitions',[], 'numGhostEntities',[], ...
                  'GhostEntities',[], 'numPoints',[], 'numCurves',[], ...
                  'numSurfaces',[],'numVolumes',[], ...
                  'Points',[],'Curves',[],'Surfaces',[],'Volumes',[]);  
    
  PartitionedEntities.numPartitions=fscanf(fid,'%d',1);
  PartitionedEntities.numGhostEntities=fscanf(fid,'%d',1);
  if PartitionedEntities.numGhostEntities>0
    R=fscanf('%d',2*PartitionedEntities.numGhostEntities);
    R=reshape(R,2,PartitionedEntities.numGhostEntities);
    PartitionedEntities.GhostEntities=struct('Tag',R(1,:),'partition',R(2,:));
  end
  R=fscanf(fid,'%d',4);
  PartitionedEntities.numPoints=R(1);
  PartitionedEntities.numCurves=R(2);
  PartitionedEntities.numSurfaces=R(3);
  PartitionedEntities.numVolumes=R(4);
  
  Points=struct('tag',[],'parentDim',[],'parentTag',[],'numPartitions',[],'partitionTags',[], ...
                'min',[],'max',[],'numPhysicalTags',[],'PhysicalTags',[]);
  Points=repmat(Points,1,PartitionedEntities.numPoints);
  for i=1:PartitionedEntities.numPoints
    %text = fgetl ( fid );
    R=fscanf(fid,'%d',4);
    Points(i).tag=R(1);Points(i).parentDim=R(2);  
    Points(i).parentTag=R(3);Points(i).numPartitions=R(4);
    if R(4)>0,Points(i).partitionTags=fscanf(fid,'%d',R(4))';end
    Points(i).min=fscanf(fid,'%g',3);
    Points(i).max=fscanf(fid,'%g',3);
    Points(i).numPhysicalTags=fscanf(fid,'%d',1);
    if Points(i).numPhysicalTags>0,Points(i).PhysicalTags=fscanf(fid,'%d',Points(i).numPhysicalTags)';end
  end
  PartitionedEntities.Points=Points;
  
  Curves=struct('tag',[],'parentDim',[],'parentTag',[],'numPartitions',[],'partitionTags',[], ...
                'min',[],'max',[],'numPhysicalTags',[],'PhysicalTags',[], ...
                'numBoundingPoints',[],'pointTags',[]);
  Curves=repmat(Curves,1,PartitionedEntities.numCurves);
  for i=1:PartitionedEntities.numCurves
    %text = fgetl ( fid );
    R=fscanf(fid,'%d',4);
    Curves(i).tag=R(1);Curves(i).parentDim=R(2);  
    Curves(i).parentTag=R(3);Curves(i).numPartitions=R(4);
    if R(4)>0,Curves(i).partitionTags=fscanf(fid,'%d',R(4))';end
    R=fscanf(fid,'%g',6);
    Curves(i).min=R(1:3);Curves(i).max=R(4:6);
    Curves(i).numPhysicalTags=fscanf(fid,'%d',1);
    if Curves(i).numPhysicalTags>0,Curves(i).PhysicalTags=fscanf(fid,'%d',Curves(i).numPhysicalTags)';end
    Curves(i).numBoundingPoints=fscanf(fid,'%d',1);
    if Curves(i).numBoundingPoints>0,Curves(i).pointTags=fscanf(fid,'%d',Curves(i).numBoundingPoints)';end
  end
  PartitionedEntities.Curves=Curves;
  
  Surfaces=struct('tag',[],'parentDim',[],'parentTag',[],'numPartitions',[],'partitionTags',[], ...
                'min',[],'max',[],'numPhysicalTags',[],'PhysicalTags',[], ...
                'numBoundingCurves',[],'curveTags',[]);
  Surfaces=repmat(Surfaces,1,PartitionedEntities.numSurfaces);
  for i=1:PartitionedEntities.numSurfaces
    %text = fgetl ( fid );
    R=fscanf(fid,'%d',4);
    Surfaces(i).tag=R(1);Surfaces(i).parentDim=R(2);  
    Surfaces(i).parentTag=R(3);Surfaces(i).numPartitions=R(4);
    if R(4)>0,Surfaces(i).partitionTags=fscanf(fid,'%d',R(4))';end
    R=fscanf(fid,'%g',6);
    Surfaces(i).min=R(1:3);Surfaces(i).max=R(4:6);
    Surfaces(i).numPhysicalTags=fscanf(fid,'%d',1);
    if Surfaces(i).numPhysicalTags>0,Surfaces(i).PhysicalTags=fscanf(fid,'%d',Surfaces(i).numPhysicalTags)';end
    Surfaces(i).numBoundingCurves=fscanf(fid,'%d',1);
    if Surfaces(i).numBoundingCurves>0,Surfaces(i).curveTags=fscanf(fid,'%d',Surfaces(i).numBoundingCurves)';end
  end
  PartitionedEntities.Surfaces=Surfaces;
  
  Volumes=struct('tag',[],'parentDim',[],'parentTag',[],'numPartitions',[],'partitionTags',[], ...
                'min',[],'max',[],'numPhysicalTags',[],'PhysicalTags',[], ...
                'numBoundingSurfaces',[],'surfaceTags',[]);
  Volumes=repmat(Volumes,1,PartitionedEntities.numVolumes);
  for i=1:PartitionedEntities.numVolumes
    %text = fgetl ( fid );
    R=fscanf(fid,'%d',4);
    Volumes(i).tag=R(1);Volumes(i).parentDim=R(2);  
    Volumes(i).parentTag=R(3);Volumes(i).numPartitions=R(4);
    if R(4)>0,Volumes(i).partitionTags=fscanf(fid,'%d',R(4))';end
    R=fscanf(fid,'%g',6);
    Volumes(i).min=R(1:3);Volumes(i).max=R(4:6);
    Volumes(i).numPhysicalTags=fscanf(fid,'%d',1);
    if Volumes(i).numPhysicalTags>0,Volumes(i).PhysicalTags=fscanf(fid,'%d',Volumes(i).numPhysicalTags)';end
    Volumes(i).numBoundingSurfaces=fscanf(fid,'%d',1);
    if Volumes(i).numBoundingSurfaces>0,Volumes(i).surfaceTags=fscanf(fid,'%d',Volumes(i).numBoundingSurfaces)';end
  end
  PartitionedEntities.Volumes=Volumes;
  
  text = fscanf(fid,'%s',1);
  if ( text == -1 ) | ~strcmp(strtok(text),'$EndPartitionedEntities') 
    error('Trouble when reading file in section $PartitionedEntities')
  else
    if verbose,fprintf('Reading $PartitionedEntities section seem OK\n');end
  end
  
end
